summaryrefslogtreecommitdiff
path: root/src/vendorcode
diff options
context:
space:
mode:
Diffstat (limited to 'src/vendorcode')
-rw-r--r--src/vendorcode/eltan/security/mboot/mboot.c4
-rw-r--r--src/vendorcode/google/chromeos/tpm2.c2
2 files changed, 3 insertions, 3 deletions
diff --git a/src/vendorcode/google/chromeos/tpm2.c b/src/vendorcode/google/chromeos/tpm2.c
index 9a99f7d285..31c28c9d2a 100644
--- a/src/vendorcode/google/chromeos/tpm2.c
+++ b/src/vendorcode/google/chromeos/tpm2.c
@@ -22,7 +22,7 @@ static void disable_platform_hierarchy(void *unused)
return;
}
- rc = tlcl_disable_platform_hierarchy();
+ rc = tlcl2_disable_platform_hierarchy();
if (rc != TPM_SUCCESS)
printk(BIOS_ERR, "Platform hierarchy disablement failed: %#x\n",
rc);
diff --git a/src/vendorcode/eltan/security/mboot/mboot.c b/src/vendorcode/eltan/security/mboot/mboot.c
index b456d2633b..9cdd0de2fe 100644
--- a/src/vendorcode/eltan/security/mboot/mboot.c
+++ b/src/vendorcode/eltan/security/mboot/mboot.c
@@ -67,7 +67,7 @@ EFI_TCG2_EVENT_ALGORITHM_BITMAP tpm2_get_active_pcrs(void)
*
* Return the TPM PCR information.
*
* This function parses the data got from tlcl_get_capability and returns the
* PcrSelection.
*
* @param[out] Pcrs The Pcr Selection
@@ -81,7 +81,7 @@ tpm_result_t tpm2_get_capability_pcrs(TPML_PCR_SELECTION *Pcrs)
tpm_result_t rc;
int index;
- rc = tlcl_get_capability(TPM_CAP_PCRS, 0, 1, &TpmCap);
+ rc = tlcl2_get_capability(TPM_CAP_PCRS, 0, 1, &TpmCap);
if (rc == TPM_SUCCESS) {
Pcrs->count = TpmCap.data.assignedPCR.count;
printk(BIOS_DEBUG, "Pcrs->count = %d\n", Pcrs->count);
@@ -67,7 +67,7 @@ EFI_TCG2_EVENT_ALGORITHM_BITMAP tpm2_get_active_pcrs(void)
* Return the TPM PCR information.
*
- * This function parses the data got from tlcl_get_capability and returns the
+ * This function parses the data got from tlcl2_get_capability and returns the
* PcrSelection.
*